@@ -6,15 +6,17 @@
 library(np)
 options(np.messages=FALSE)
 
+set.seed(42)
+
 n <- 1000
 
-set.seed(42)
 x <- runif(n)
 z1 <- rbinom(n,1,.5)
 z2 <- rbinom(n,1,.5)
 y <- cos(2*pi*x) + z1 + rnorm(n,sd=.25)
-mydat <- data.frame(y,x,z1=factor(z1),z2=factor(z2))
-rm(x,y,z1,z2)
+z1 <- factor(z1)
+z2 <- factor(z2)
+mydat <- data.frame(y,x,z1,z2)
 
 ## A regression example (local constant, least-squares cross-validation)
 
@@ -25,7 +27,8 @@ t <- system.time(bw <- npregbw(y~x+z1+z2,
 
 summary(bw)
 
-t <- t + system.time(model <- npreg(bws=bw))
+t <- t + system.time(model <- npreg(bws=bw,
+                                    data=mydat))
 
 summary(model)
 
